<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="soundKonverter" version="2">
    <MenuBar>
        <Menu name="file">
            <Action name="add_files" />
            <Action name="add_folder" />
            <Action name="add_audiocd" />
            <Action name="add_url" />
            <Separator />
            <Action name="load" />
            <Action name="save" />
        </Menu>
        <Menu name="conversion"><Text>&amp;Conversion</Text>
            <Action name="start" />
            <Action name="stopMenu" />
<!--             <Action name="priorityMenu" /> -->
            <Action name="log" />
        </Menu>
        <Menu name="tools">
            <Action name="replaygainscanner" />
            <Action name="cuesheeteditor" />
        </Menu>
        <!--<Menu name="help">
            <Action name="about_plugins" />
        </Menu>-->
    </MenuBar>
    <ToolBar name="mainToolBar" hidden="true"><Text>Main Toolbar</Text>
        <Action name="add_files" />
        <Action name="add_folder" />
        <Action name="add_audiocd" />
        <Action name="add_url" />
        <Separator lineSeparator="true" />
        <Action name="start" />
        <Action name="stopMenu" />
<!--         <Action name="priorityMenu" /> -->
        <Separator />
        <Action name="replaygainscanner" />
        <Action name="cuesheeteditor" />
    </ToolBar>
</kpartgui>
